from setuptools import setup, find_packages

import maleta

setup(
    name='maleta',
    version=maleta.__version__,
    packages=find_packages(),
    author="Sebastien Campion",
    author_email="sebastien.campion@pwc.com",
    description="maleta client module",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Development Status :: 1 - Planning",
        "License :: OSI Approved",
        "Natural Language :: French",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.6",
        "Topic :: Communications",
    ],
    license="AGPL",
)
